antares.apps.thirdparty package — Antares 0.0.2 documentation

# antares.apps.thirdparty package

## Subpackages

- antares.apps.thirdparty.migrations package
  - Module contents
- antares.apps.thirdparty.models package
  - Submodules
  - antares.apps.thirdparty.models.third_party_detail module
  - antares.apps.thirdparty.models.third_party_record module
  - Module contents
- antares.apps.thirdparty.tests package
  - Module contents
- antares.apps.thirdparty.views package
  - Module contents

## Submodules

## antares.apps.thirdparty.admin module

## antares.apps.thirdparty.apps module

class `antares.apps.thirdparty.apps.` `ThirdpartyConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'thirdparty'

## antares.apps.thirdparty.constants module

## antares.apps.thirdparty.urls module

## Module contents